summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorHans-Peter Nilsson <hp@axis.com>2004-12-01 02:29:30 +0000
committerHans-Peter Nilsson <hp@axis.com>2004-12-01 02:29:30 +0000
commitcf2182e22ee4c4a40ec459238d28b91937e00a41 (patch)
tree9d410d392f25cd41e407a9df0f2688b251193387
parent6c12025dad89554fdea7111e85db1f35ec537a6a (diff)
downloadgdb-cf2182e22ee4c4a40ec459238d28b91937e00a41.tar.gz
* cgen.sh: New thirteenth parameter opcfile, defaulting to
/dev/null. <case desc>: Pass -OPC opcfile. * Make-common.in (cgen-desc): Pass $(opcfile) as thirteenth parameter to cgen.sh.
-rw-r--r--sim/common/Make-common.in2
-rw-r--r--sim/common/cgen.sh6
2 files changed, 6 insertions, 2 deletions
diff --git a/sim/common/Make-common.in b/sim/common/Make-common.in
index 6ccf986103d..dbcc0ebe169 100644
--- a/sim/common/Make-common.in
+++ b/sim/common/Make-common.in
@@ -739,6 +739,6 @@ cgen-desc: force
$(SHELL) $(srccom)/cgen.sh desc $(srcdir) \
$(CGEN) $(CGENDIR) "$(CGENFLAGS)" \
$(arch) "$(FLAGS)" $(cpu) "$(isa)" $(mach) "$(SUFFIX)" \
- $(archfile) ignored
+ $(archfile) ignored $(opcfile)
## End COMMON_POST_CONFIG_FRAG
diff --git a/sim/common/cgen.sh b/sim/common/cgen.sh
index 172edcb7ca3..87188354683 100644
--- a/sim/common/cgen.sh
+++ b/sim/common/cgen.sh
@@ -3,7 +3,7 @@
#
# Usage: /bin/sh cgen.sh {"arch"|"cpu"|"decode"|"defs"|"cpu-decode"} \
# srcdir cgen cgendir cgenflags \
# arch archflags cpu mach suffix archfile extrafiles
#
# We store the generated files in the source directory until we decide to
# ship a Scheme interpreter (or other implementation) with gdb/binutils.
@@ -26,9 +26,12 @@ shift ; mach=$9
shift ; suffix=$9
shift ; archfile=$9
shift ; extrafiles=$9
+shift ; opcfile=$9
rootdir=${srcdir}/../..
+test -z "${opcfile}" && opcfile=/dev/null
+
if test -z "$isa" ; then
isa=all
prefix=$cpu
@@ -196,6 +199,7 @@ desc)
${cgen} -s ${cgendir}/cgen-opc.scm \
-s ${cgendir} \
${cgenflags} \
+ -OPC ${opcfile} \
-f "${archflags}" \
-m ${mach} \
-a ${archfile} \
@@ -3,7 +3,7 @@
# Usage: /bin/sh cgen.sh {"arch"|"cpu"|"decode"|"defs"|"cpu-decode"} \
# srcdir cgen cgendir cgenflags \
-# arch archflags cpu mach suffix archfile extrafiles
+# arch archflags cpu mach suffix archfile extrafiles opcfile
#
# We store the generated files in the source directory until we decide to